@@ -43,6 +43,16 @@ make_naive_Bayes_naivebayes <- function() {
     )
   )
 
+  parsnip::set_encoding(
+    model = "naive_Bayes",
+    eng = "naivebayes",
+    mode = "classification",
+    options = list(
+      predictor_indicators = "none",
+      compute_intercept = FALSE,
+      remove_intercept = FALSE
+    )
+  )
 
   parsnip::set_pred(
     model = "naive_Bayes",
@@ -120,6 +130,17 @@ make_naive_Bayes_klaR <- function() {
     )
   )
 
+  parsnip::set_encoding(
+    model = "naive_Bayes",
+    eng = "klaR",
+    mode = "classification",
+    options = list(
+      predictor_indicators = "none",
+      compute_intercept = FALSE,
+      remove_intercept = FALSE
+    )
+  )
+
   parsnip::set_pred(
     model = "naive_Bayes",
     eng = "klaR",
